NetBSD-Bugs archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
Re: kern/44980
The following reply was made to PR kern/44980; it has been noted by GNATS.
From: Martijn van Buul <martijn.van.buul%gmail.com@localhost>
To: gnats-bugs%netbsd.org@localhost
Cc:
Subject: Re: kern/44980
Date: Wed, 18 May 2011 08:33:33 +0200
Urgh, why do I still trust webmail clients.
Index: ums.c
===================================================================
RCS file: /cvsroot/src/sys/dev/usb/ums.c,v
retrieving revision 1.81
diff -u -r1.81 ums.c
--- ums.c 3 Nov 2010 22:34:24 -0000 1.81
+++ ums.c 18 May 2011 06:33:33 -0000
@@ -282,15 +282,19 @@
}
/*
* The Microsoft Wireless Laser Mouse 6000 v2.0 reports a bad
* position for the wheel and wheel tilt controls -- should be
* in bytes 3 & 4 of the report. Fix this if necessary.
*/
if (uha->uaa->vendor == USB_VENDOR_MICROSOFT &&
(uha->uaa->product == USB_PRODUCT_MICROSOFT_24GHZ_XCVR10 ||
- uha->uaa->product == USB_PRODUCT_MICROSOFT_24GHZ_XCVR20)) {
+ uha->uaa->product == USB_PRODUCT_MICROSOFT_24GHZ_XCVR20 ||
+ uha->uaa->product == 0x077d ||
+ uha->uaa->product == 0x00e1)) {
if ((sc->flags & UMS_Z) && sc->sc_loc_z.pos == 0)
- sc->sc_loc_z.pos = 24;
+ sc->sc_loc_z.pos = sc->sc_loc_y.pos +
+ sc->sc_loc_y.size;
if ((sc->flags & UMS_W) && sc->sc_loc_w.pos == 0)
sc->sc_loc_w.pos = sc->sc_loc_z.pos + 8;
}
@@ -282,15 +282,19 @@
}
/*
- * The Microsoft Wireless Laser Mouse 6000 v2.0 reports a bad
- * position for the wheel and wheel tilt controls -- should be
- * in bytes 3 & 4 of the report. Fix this if necessary.
+ * Several Microsoft mice report a bad position for the wheel
+ * and tilt controls -- depending on the size of the X- and Y-
+ * control it should either be in bytes 3&4 or 5&6. Fix this
+ * if necessary.
*/
if (uha->uaa->vendor == USB_VENDOR_MICROSOFT &&
Home |
Main Index |
Thread Index |
Old Index